<?php 

// Change user info
$lang['title'] = 'Редагування акаунта';
$lang['button_text'] = 'Завантажити';
$lang['ln_photo'] = 'Розмір {width} х {height} пікс';
$lang['ln_birth_date'] = 'Дата народження';
$lang['Default language'] = 'Мова за замовчуванням';
$lang['ln_email'] = 'Email';
$lang['ln_name'] = 'Ім\'я';
$lang['ln_soname'] = 'Прізвище';
$lang['ln_about'] = 'пару слів про себе';
