<a data-toggle="dropdown" href="#" class="dropdown-toggle" id="dLabel">
    <i class="fa fa-user" aria-hidden="true"></i>
</a>
<ul class="dropdown-menu dropdown-menu-right">
    <li><span>{userinfo_hi}, {user_name}</span></li>
    <li role="presentation" class="divider"></li>
    <li><a href="{link}/change_pass"><i class="fa fa-lock" aria-hidden="true"></i> {menu_change_pass}</a></li>
    <li><a href="{link}/change_info"><i class="fa fa-cog" aria-hidden="true"></i> {menu_change_info}</a></li>
    <li role="presentation" class="divider"></li>
    <li><a href="/<?=$this->config->item('admin_page'); ?>/logout"><i class="fa fa-sign-out" aria-hidden="true"></i> <?= $this->lang->line('exit_btn') ?></a></li>
</ul>