<?php 

$lang['userinfo_hi'] = 'Hello';

$lang['menu_change_pass'] = 'Edit password';
$lang['menu_change_info'] = 'Edit information';

$lang['btn_save'] = 'Save';
$lang['btn_cancel'] = 'Cancel';

$lang['msg_ok'] = 'Data was successfully changed';