{form_open}
<div class="alert alert-success" style="display:none" id="msg_ok">{msg_ok}</div>
<div class="control-group">
    <label class="control-label" for="oldpass">{old_pass}</label>
    <div class="controls">
        <input type="password" id="oldpass" placeholder="{old_pass}" name="oldpass">
    </div>
</div>
<div class="control-group">
    <label class="control-label" for="newpass">{new_pass}</label>
    <div class="controls">
        <input type="password" id="newpass" placeholder="{new_pass}" name="newpass">
    </div>
</div>
<div class="control-group">
    <label class="control-label" for="newpassconf">{new_pass_conf}</label>
    <div class="controls">
        <input type="password" id="newpassconf" placeholder="{new_pass_conf}" name="newpassconf">
    </div>
</div>
<div class="form-actions">
    <button type="submit" class="btn btn-primary" id="btn_save">{btn_save}</button>
</div>
{form_close}