<?php 

// Change user info
$lang['title'] = 'Edit user account';
$lang['button_text'] = 'Download';
$lang['ln_photo'] = 'Size {width} х {height} px';
$lang['ln_birth_date'] = 'Date of birth';
$lang['Default language'] = 'Default language';
$lang['ln_email'] = 'Email';
$lang['ln_name'] = 'Name';
$lang['ln_soname'] = 'Surname';
$lang['ln_about'] = 'Additional information';
