$(document).ready(function() {
    $('#btn_save').click(function(){
        var link = $('#change_form').attr('action');
        $.post(link, $('#change_form').serialize(), function(data) {
            var obj = jQuery.parseJSON(data);
            $('#change_form .error').removeClass('error');
            $('#msg_ok').hide();
            if (typeof obj.errors != 'undefined') {
                jQuery.each(obj.errors, function(k, v) {
                    $('#' + v).parents('div.control-group').addClass('error');
                });
            } else {
                $('#msg_ok').show('slow');
            }
        });
            
        return false;
    });
    $('#btn_cancel').click(function(){
        $('#change_form')[0].reset();
        return false;
    });
})