.account .preview-part{
    float: left;
    margin-top: 7px;
    font-size: 13px;
}
.btn:active, .btn.active{
    background-color: #ccc  \9
}
.btn:first-child{
    *margin-left: 0
}
.account .portrait{
    width: 256px;
    height: 256px;
    background-color: #ebebeb;
}
.account .info-part{
    float: left;
    margin-top: -4px;
    width: 944px;
}
.account textarea{
    max-width: 663px;
    min-width: 663px;
    width: 663px !important;
    margin-bottom: 10px;
}
.account input[type="email"],
.account input[type="text"],
.account select{
    padding: 6px 6px;
    margin-bottom: 7px;
    width: 663px;
}
.account select{
    width: 150px;
    float: left
}
.account .date{
    width: 150px !important;
    text-align: center;
    float: left;
}
.account td:first-of-type{
    width: 240px;
    padding-right: 16px;
    padding-left: 33px;
}
.account h5{
    text-transform: uppercase;
    text-align: left;
}
.account td{
    text-align: right;
    vertical-align: top;
    line-height: 38px;
    height: 43px;
}
.account tr:last-of-type td:last-of-type{
    text-align: left;
}
.account .about{
    margin: 0;
}
.account tr:last-of-type td{
    text-align: left;
}
.account tr:last-of-type button{
    margin-top: 68px;
    padding: 4px 20px;
    font-weight: bold;
    font-size: 12px;
}
.account tr:last-of-type button:first-of-type{
    margin-right: 25px;
}
.account .no-indent ~ tr td{
    position: relative;
    top: -40px;
    line-height: 70px;
}