<?php 

// Change user info
$lang['title'] = 'Редактирование акаунта';
$lang['button_text'] = 'Загрузить';
$lang['ln_photo'] = 'Размер {width} х {height} пикс';
$lang['ln_birth_date'] = 'Дата рождиния';
$lang['Default language'] = 'Язык по умолчанию';
$lang['ln_email'] = 'Email';
$lang['ln_name'] = 'Имя';
$lang['ln_soname'] = 'Фамилия';
$lang['ln_about'] = 'пару слов о себе';
