<?php 

$lang['userinfo_hi'] = 'Привіт';

$lang['menu_change_pass'] = 'Змінити пароль';
$lang['menu_change_info'] = 'Змінити інформацію';

$lang['btn_save'] = 'Зберегти';
$lang['btn_cancel'] = 'Відміна';

$lang['msg_ok'] = 'Дані успішно змінено';