<?php 

$lang['userinfo_hi'] = 'Привет';

$lang['menu_change_pass'] = 'Изменить пароль';
$lang['menu_change_info'] = 'Изменить информацию';

$lang['btn_save'] = 'Сохранить';
$lang['btn_cancel'] = 'Отмена';

$lang['msg_ok'] = 'Данные успешно изменены';